"""Top-level package for jmanager."""

__author__ = """Yasunori Horikoshi"""
__email__ = "horikoshi.et.al@gmail.com"
__version__ = "1.3.2"
